CREATE TABLE JCR_CONTAINER(
  VERSION VARCHAR(255) NOT NULL
);
ALTER TABLE JCR_CONTAINER ADD CONSTRAINT JCR_PK_CONTAINER PRIMARY KEY(VERSION);
CREATE TABLE JCR_SITEM(
    ID VARCHAR2(255) NOT NULL,
    VERSION INTEGER NOT NULL,
    CONTAINER_NAME VARCHAR2(255) NOT NULL,
    PATH VARCHAR2(4000) NOT NULL
);
ALTER TABLE JCR_SITEM ADD CONSTRAINT JCR_PK_SITEM PRIMARY KEY(ID);
ALTER TABLE JCR_SITEM ADD CONSTRAINT JCR_CU_SITEM_ID UNIQUE (ID, PATH, CONTAINER_NAME, VERSION);
ALTER TABLE JCR_SITEM ADD CONSTRAINT JCR_CU_SITEM_PATH UNIQUE (PATH, CONTAINER_NAME, ID, VERSION);
CREATE TABLE JCR_SNODE(
    ID VARCHAR2(255) NOT NULL,
    ORDER_NUM INTEGER,
    PARENT_ID VARCHAR2(255),
);
ALTER TABLE JCR_SNODE ADD CONSTRAINT JCR_PK_SNODE PRIMARY KEY(ID);
ALTER TABLE JCR_SNODE ADD CONSTRAINT JCR_FK_SNODE_PARENT FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID);
ALTER TABLE JCR_SNODE ADD CONSTRAINT JCR_FK_SNODE_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID);
ALTER TABLE JCR_SNODE ADD CONSTRAINT JCR_CU_SNODE_PARENT UNIQUE (ID, PARENT_ID, ORDER_NUM);
ALTER TABLE JCR_SNODE ADD CONSTRAINT JCR_CU_SNODE_PARENTID UNIQUE (PARENT_ID, ID, ORDER_NUM);
CREATE TABLE JCR_SPROPERTY(
    ID VARCHAR2(255) NOT NULL,
    TYPE INTEGER NOT NULL,
    PARENT_ID VARCHAR2(255) NOT NULL,
    MULTIVALUED INTEGER NOT NULL
);
ALTER TABLE JCR_SPROPERTY ADD CONSTRAINT JCR_PK_SPROPERTY PRIMARY KEY(ID);
ALTER TABLE JCR_SPROPERTY ADD CONSTRAINT JCR_FK_SPROPERTY_NODE FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID);
ALTER TABLE JCR_SPROPERTY ADD CONSTRAINT JCR_FK_SPROPERTY_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID);
ALTER TABLE JCR_SPROPERTY ADD CONSTRAINT JCR_CU_SPROPERTY_PARENT UNIQUE (ID, PARENT_ID);
ALTER TABLE JCR_SPROPERTY ADD CONSTRAINT JCR_CU_SPROPERTY_PARENTID UNIQUE (PARENT_ID, ID);
CREATE TABLE JCR_SVALUE(
    ID INTEGER,
    DATA BLOB,
    ORDER_NUM INTEGER,
    PROPERTY_ID VARCHAR2(255) NOT NULL
);
ALTER TABLE JCR_SVALUE ADD CONSTRAINT JCR_PK_SVALUE PRIMARY KEY(ID);
ALTER TABLE JCR_SVALUE ADD CONSTRAINT JCR_FK_SVALUE_PROPERTY FOREIGN KEY(PROPERTY_ID) REFERENCES JCR_SPROPERTY(ID);
ALTER TABLE JCR_SVALUE ADD CONSTRAINT JCR_CU_SVALUE_PROPERTY UNIQUE (PROPERTY_ID, ORDER_NUM);
CREATE sequence JCR_SVALUE_SEQ
/
CREATE OR REPLACE trigger BI_JCR_SVALUE
  before insert on JCR_SVALUE
  for each row
begin
  SELECT JCR_SVALUE_SEQ.nextval INTO :NEW.ID FROM dual;
end;
/
CREATE TABLE JCR_SREF(
  NODE_ID VARCHAR(255) NOT NULL,
  PROPERTY_ID VARCHAR(255) NOT NULL,
  ORDER_NUM INTEGER NOT NULL
);
ALTER TABLE JCR_SREF ADD CONSTRAINT JCR_PK_SREF PRIMARY KEY(NODE_ID, PROPERTY_ID, ORDER_NUM);
ALTER TABLE JCR_SREF ADD CONSTRAINT JCR_CU_SREF_PROPERTY UNIQUE (PROPERTY_ID, ORDER_NUM);
