CREATE TABLE JCR_CONTAINER(
	VERSION VARCHAR(255) NOT NULL,
	CONSTRAINT JCR_PK_CONTAINER PRIMARY KEY(VERSION)
);
CREATE TABLE JCR_SITEM(
	ID VARCHAR(255) NOT NULL,
	VERSION INTEGER NOT NULL,
	CONTAINER_NAME VARCHAR(255) NOT NULL,
	PATH VARCHAR(1024) NOT NULL,
	CONSTRAINT JCR_PK_SITEM PRIMARY KEY(ID),
  	CONSTRAINT JCR_CU_SITEM_ID UNIQUE (ID, PATH, CONTAINER_NAME, VERSION),
  	CONSTRAINT JCR_CU_SITEM_PATH UNIQUE (PATH, CONTAINER_NAME, ID, VERSION)
);
CREATE TABLE JCR_SNODE(
	ID VARCHAR(255) NOT NULL,
	ORDER_NUM INTEGER,
	PARENT_ID VARCHAR(255),
	CONSTRAINT JCR_PK_SNODE PRIMARY KEY(ID),
    CONSTRAINT JCR_FK_SNODE_PARENT FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID),
    CONSTRAINT JCR_FK_SNODE_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID),
	CONSTRAINT JCR_CU_SNODE_PARENT UNIQUE (ID, PARENT_ID, ORDER_NUM),
	CONSTRAINT JCR_CU_SNODE_PARENTID UNIQUE (PARENT_ID, ID, ORDER_NUM)
);
CREATE TABLE JCR_SPROPERTY(
	ID VARCHAR(255) NOT NULL,
	TYPE INTEGER NOT NULL,
	PARENT_ID VARCHAR(255) NOT NULL,
	MULTIVALUED BOOLEAN NOT NULL,
	CONSTRAINT JCR_PK_SPROPERTY PRIMARY KEY(ID),
    CONSTRAINT JCR_FK_SPROPERTY_NODE FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID),
    CONSTRAINT JCR_FK_SPROPERTY_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID),
	CONSTRAINT JCR_CU_SPROPERTY_PARENT UNIQUE (ID, PARENT_ID),
	CONSTRAINT JCR_CU_SPROPERTY_PARENTID UNIQUE (PARENT_ID, ID)
);
CREATE TABLE JCR_SVALUE(
	ID BIGINT generated by default as identity (START WITH 2, INCREMENT BY 1) NOT NULL, 
	DATA VARBINARY(65535) NOT NULL,
	ORDER_NUM INTEGER,
	PROPERTY_ID VARCHAR(255) NOT NULL,
	CONSTRAINT JCR_PK_SVALUE PRIMARY KEY(ID),
	CONSTRAINT JCR_FK_SVALUE_PROPERTY FOREIGN KEY(PROPERTY_ID) REFERENCES JCR_SPROPERTY(ID),
	CONSTRAINT JCR_CU_SVALUE_PROPERTY UNIQUE (PROPERTY_ID, ORDER_NUM)
);
CREATE TABLE JCR_SREF(
  NODE_ID VARCHAR(255) NOT NULL, 
  PROPERTY_ID VARCHAR(255) NOT NULL,
  ORDER_NUM INTEGER NOT NULL,  
  CONSTRAINT JCR_PK_SREF PRIMARY KEY(NODE_ID, PROPERTY_ID, ORDER_NUM),
  CONSTRAINT JCR_CU_SREF_PROPERTY UNIQUE (PROPERTY_ID, ORDER_NUM)
);